<?php
defined( 'ABSPATH' ) || exit;

class DVloading_Class {
    /* The single instance of the class */
	protected static $_instance = null;

    /* Main Instance */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

    /* Constructor */
    public function __construct() {
        add_action('wp_head',array($this, 'head') , 1);
        add_action('wp_footer', array($this, 'loading_screen'), 1);
        add_action('wp_enqueue_scripts',array($this, 'enqueue_scripts'));
    }

    /* Activation check */
    public function mode() {
        $mode = dvloading_get_option('dvloading_options','placement','allpages');
        return $mode;
    }

    /* Add required scripts to hide everything before print to avoid blink */
    public function get_head() { 
        $bgcolor = dvloading_get_option('dvloading_options','bgcolor', '#1F2041');
        ?>
        <script type="text/javascript">document.documentElement.className += ' isg-page-loading-fix-html ';</script>
        <style type="text/css">html.isg-page-loading-fix-html {background-color: <?php echo esc_attr($bgcolor); ?>} html.isg-page-loading-fix-html * {visibility: hidden;}html.isg-page-loading-fix-html #isg-page-loading {visibility: visible;}</style>
    <?php }

    public function head() {
        $archive = dvloading_get_option('dvloading_options','archive', 'enable' );
        $posttypes = dvloading_get_option('dvloading_options','posttypes', array('post', 'page') ); 

        if ($this->mode() == 'allpages') {
            $this->get_head();
        } elseif (($archive == 'enable') && (is_archive() || is_404())) {
            $this->get_head();
        } elseif (($this->mode() == 'homepage') && (is_front_page())) {
            $this->get_head();
        } elseif($this->mode() == 'posttype') { 
            if (!empty($posttypes)) {
                if (is_singular($posttypes)) {
                    $this->get_head();
                }
            }
        }
    }

    /* Get Scripts */
    public function get_scripts(){
        // Get Settings
        $custom_css = dvloading_get_option('dvloading_options','custom_css', '');
        $fontfamily = dvloading_get_option('dvloading_options_1','font_family','default');
        $titlelineheight = dvloading_get_option('dvloading_options_1','titlelineheight', '1.3');
        $subtitlelineheight = dvloading_get_option('dvloading_options_1','subtitlelineheight', 1);
        $titlefontsize = dvloading_get_option('dvloading_options_1','titlefontsize', 90);
        $subtitlefontsize = dvloading_get_option('dvloading_options_1','subtitlefontsize', 40);
        $desktop = dvloading_get_option('dvloading_options_1','desktop', 82);
        $tabletlandscape = dvloading_get_option('dvloading_options_1','tabletlandscape', 72);
        $tabletportrait = dvloading_get_option('dvloading_options_1','tabletportrait', 64);
        $phonelandscape = dvloading_get_option('dvloading_options_1','phonelandscape', 56);
        $phoneportrait = dvloading_get_option('dvloading_options_1','phoneportrait', 48);
        $smalldevices = dvloading_get_option('dvloading_options_1','smalldevices',40);
        $subdesktop = dvloading_get_option('dvloading_options_1','subdesktop', 36);
        $subtabletlandscape = dvloading_get_option('dvloading_options_1','subtabletlandscape',30);
        $subtabletportrait = dvloading_get_option('dvloading_options_1','subtabletportrait',26);
        $subphonelandscape = dvloading_get_option('dvloading_options_1','subphonelandscape',24);
        $subphoneportrait = dvloading_get_option('dvloading_options_1','subphoneportrait',20);
        $subsmalldevices = dvloading_get_option('dvloading_options_1','subsmalldevices',18);
        $disabletextmobile = dvloading_get_option('dvloading_options_1','disabletextmobile', 'enable');    
        $skipfontsize = dvloading_get_option('dvloading_options_2','skipfontsize', 16);
        $skiptabletsize = dvloading_get_option('dvloading_options_2','skiptabletsize',15);
        $skipphonesize = dvloading_get_option('dvloading_options_2','skipphonesize',14);   
        $skipleftright = dvloading_get_option('dvloading_options_2','skipleftright', 20);
        $skiptopbottom = dvloading_get_option('dvloading_options_2','skiptopbottom',20);
        $counterfontsize = dvloading_get_option('dvloading_options_2','counterfontsize',40);
        $countertabletsize = dvloading_get_option('dvloading_options_2','countertabletsize',30);
        $counterphonesize = dvloading_get_option('dvloading_options_2','counterphonesize',20);   
        $counterleftright = dvloading_get_option('dvloading_options_2','counterleftright',20);
        $countertopbottom = dvloading_get_option('dvloading_options_2','countertopbottom',20);
        $gifsize = dvloading_get_option('dvloading_options_2','gifsize',64);
        $bgcolor = dvloading_get_option('dvloading_options','bgcolor','#1F2041');
        $titlecolor = dvloading_get_option('dvloading_options_1','titlecolor','rgba(255, 255, 255, 0.1)');
        $loadedtitlecolor = dvloading_get_option('dvloading_options_1','loadedtitlecolor','#ffffff');
        $subtitlecolor = dvloading_get_option('dvloading_options_1','subtitlecolor','rgba(255, 255, 255, 0.1)');
        $loadedsubtitlecolor = dvloading_get_option('dvloading_options_1','loadedsubtitlecolor','rgba(255, 255, 255, 0.3)');
        $barcolor = dvloading_get_option('dvloading_options_2','barcolor','rgba(255, 255, 255, 0.1)');
        $loadedbarcolor = dvloading_get_option('dvloading_options_2','loadedbarcolor','#ffffff');
        $barheight = dvloading_get_option('dvloading_options_2','barheight',3);
        $rounding = dvloading_get_option('dvloading_options_2','rounding', '0');
        $skipcolor = dvloading_get_option('dvloading_options_2','skipcolor','#ffffff');
        $countercolor = dvloading_get_option('dvloading_options_2','countercolor','#ffffff');

        $testmode = dvloading_get_option('dvloading_options','testmode', 'disable');
        $animationstyle = dvloading_get_option('dvloading_options','animationstyle','text' );
        $showskip = dvloading_get_option('dvloading_options_2','showskip','enable' );
        $barplacement = dvloading_get_option('dvloading_options_2','barplacement','isgbottombar' );
        $skipdelay = dvloading_get_option('dvloading_options_2','skipdelay', 1000 );
        $showcounter = dvloading_get_option('dvloading_options_2','showcounter', 'enable' );
        $transition = dvloading_get_option('dvloading_options','transition', 'enable' );
        $pagetransition = dvloading_get_option('dvloading_options','pagetransitions','bounceOut' );
        $imageanimation = dvloading_get_option('dvloading_options_2','imageanimation', 'enable' );
        $imageduration = dvloading_get_option('dvloading_options_2','imageduration','normal' );

        // Main Styles & Scripts
        wp_enqueue_style('dvloading_styles', plugin_dir_url( __FILE__ ) . 'css/style.css', true, '1.0');

        if ( $transition == 'enable' ) {
            wp_enqueue_style('dvloading_animations', plugin_dir_url( __FILE__ ) . 'css/animations.css', true, '1.0');
        }
        if ($imageanimation != 'disable') {
            wp_enqueue_style('dvloading_imganimations', plugin_dir_url( __FILE__ ) . 'css/imganimations.css', true, '1.0');
        }
        if ( $showcounter == 'enable' ) {
            wp_enqueue_script('dvloading_counter', plugin_dir_url( __FILE__ ) . 'js/counter.js', array( 'jquery' ), '1.0.0', true );
        }

        // Custom Styles
        $inline_style = '';

        if ($fontfamily != 'default') {
            $inline_style .= '#isg-page-loading,#isg-loading-text,#isg-loading-sub-text, #isg-skip-inner,#isg-percentage-inner {font-family:' . $fontfamily . '}';
        }

        $inline_style .= '#isg-loading-gif img,#isg-loading-image img {width:' . $gifsize . 'px}';
        $inline_style .= '#isg-page-loading #isg-loading-text {font-size:' . $titlefontsize . 'px}';
        $inline_style .= '#isg-page-loading #isg-loading-sub-text {font-size:' . $subtitlefontsize . 'px}';
        $inline_style .= '#isg-loading-text {line-height:' . $titlelineheight . '}';
        $inline_style .= '#isg-skip-inner {font-size:' . $skipfontsize . 'px}';
        $inline_style .= '#isg-skip-inner {margin:' . $skiptopbottom . 'px ' . $skipleftright . 'px}';
        $inline_style .= '#isg-loading-sub-text {line-height:' . $subtitlelineheight . '}';
        $inline_style .= '#isg-percentage-inner {font-size:' . $counterfontsize . 'px}';
        $inline_style .= '#isg-percentage-inner {margin:' . $countertopbottom . 'px ' . $counterleftright . 'px}';
        $inline_style .= '@media only screen and (max-width: 1200px) {#isg-page-loading #isg-loading-text {font-size:' . $desktop . 'px}#isg-page-loading #isg-loading-sub-text {font-size:' . $subdesktop . 'px}}';
        $inline_style .= '@media only screen and (max-width: 1024px) {#isg-page-loading #isg-loading-text {font-size:' . $tabletlandscape . 'px}#isg-page-loading #isg-loading-sub-text {font-size:' . $subtabletlandscape . 'px}#isg-skip-inner {font-size:' . $skiptabletsize . 'px}#isg-percentage-inner {font-size:' . $countertabletsize . 'px}}';
        if ($disabletextmobile == 'enable') {
            $inline_style .= '@media only screen and (max-width: 1024px) {#isg-loading-text:before {width: 100% !important;}}';
        }
        $inline_style .= '@media only screen and (max-width: 768px) {#isg-page-loading #isg-loading-text {font-size:' . $tabletportrait . 'px}#isg-page-loading #isg-loading-sub-text {font-size:' . $subtabletportrait . 'px}}';
        $inline_style .= '@media only screen and (max-width: 640px) {#isg-page-loading #isg-loading-text {font-size:' . $phonelandscape . 'px}#isg-page-loading #isg-loading-sub-text {font-size:' . $subphonelandscape . 'px}}';
        $inline_style .= '@media only screen and (max-width: 480px) {#isg-page-loading #isg-loading-text {font-size:' . $phoneportrait . 'px}#isg-page-loading #isg-loading-sub-text {font-size:' . $subphoneportrait . 'px}#isg-skip-inner {font-size:' . $skipphonesize . 'px}#isg-percentage-inner {font-size:' . $counterphonesize . 'px}}';
        $inline_style .= '@media only screen and (max-width: 340px) {#isg-page-loading #isg-loading-text {font-size:' . $smalldevices . 'px}#isg-page-loading #isg-loading-sub-text {font-size:' . $subsmalldevices . 'px}}';

        $inline_style .= '#isg-page-loading,html.isg-page-loading-fix-html {background-color:' . $bgcolor . '}';
        $inline_style .= '#isg-loading-text {color:' . $titlecolor . '}';
        $inline_style .= '#isg-loading-text:before {color:' . $loadedtitlecolor . '}';
        $inline_style .= '#isg-loading-sub-text {color:' . $subtitlecolor . '}';
        $inline_style .= '#isg-loading-sub-text.loaded-subtitle {color:' . $loadedsubtitlecolor . '}';
        $inline_style .= '#isg-loading-bar {background:' . $barcolor . '}';
        $inline_style .= '#isg-loading-bar:before {background:' . $loadedbarcolor . '}';
        $inline_style .= '#isg-loading-bar,#isg-loading-bar:before {height:' . $barheight . 'px}';
        $inline_style .= '#isg-loading-gif img,#isg-loading-image img {border-radius:' . $rounding . '%}';
        $inline_style .= '#isg-skip-inner {color:' . $skipcolor . '}';
        $inline_style .= '#isg-percentage-inner {color:' . $countercolor . '}';

        if (!empty($custom_css)) {
            $inline_style .= $custom_css;
        }

        wp_add_inline_style( 'dvloading_styles', $inline_style );

        // Custom Script
        wp_enqueue_script('dvloading-custom', plugin_dir_url( __FILE__ ) . 'js/custom.js', array( 'jquery' ), '2.0.0', true );

        $dvloading_param = array(
			"testmode" => $testmode,
            "animationstyle" => $animationstyle,
            "showskip" => $showskip,
            "barplacement" => $barplacement,
            "skipdelay" => $skipdelay,
            "showcounter" => $showcounter,
            "transition" => $transition,
            "pagetransition" => $pagetransition,
            "imageanimation" => $imageanimation,
            "imageduration" => $imageduration
		);
		wp_localize_script('dvloading-custom', 'dvloading_vars', $dvloading_param);

    }

    /* Enqueue Scripts */
    public function enqueue_scripts(){
        $archive = dvloading_get_option('dvloading_options','archive', 'enable' );
        $posttypes = dvloading_get_option('dvloading_options','posttypes', array('post', 'page') ); 

        wp_enqueue_script('dvloading_fix', plugin_dir_url( __FILE__ ) . 'js/fix.js', array( 'jquery' ), '1.0.0', false );

        if ($this->mode() == 'allpages') {
            $this->get_scripts();
        } elseif (($archive == 'enable') && (is_archive() || is_404())) {
            $this->get_scripts();
        } elseif (($this->mode() == 'homepage') && (is_front_page())) {
            $this->get_scripts();
        } elseif($this->mode() == 'posttype') { 
            if (!empty($posttypes)) {
                if (is_singular($posttypes)) {
                    $this->get_scripts();
                }
            }
        }
    }

    /* Loading Screen */
    public function loading_screen() {
        $archive = dvloading_get_option('dvloading_options','archive', 'enable' );
        $posttypes = dvloading_get_option('dvloading_options','posttypes', array('post', 'page') ); 

        if ($this->mode() == 'allpages') {
            $this->get_loading_screen();
        } elseif (($archive == 'enable') && (is_archive() || is_404())) {
            $this->get_loading_screen();
        } elseif (($this->mode() == 'homepage') && (is_front_page())) {
            $this->get_loading_screen();
        } elseif($this->mode() == 'posttype') { 
            if (!empty($posttypes)) {
                if (is_singular($posttypes)) {
                    $this->get_loading_screen();
                }
            }
        }
    }

    public function get_loading_screen() {
        $titletext = dvloading_get_option('dvloading_options_1','titletext',esc_html__( 'Loading...', 'dvloading'));
        $subtitletext = dvloading_get_option('dvloading_options_1','subtitletext','');
        $barplacement = dvloading_get_option('dvloading_options_2','barplacement','isgbottombar');
        $animationstyle = dvloading_get_option('dvloading_options','animationstyle','text');
        $animatedgif = dvloading_get_option('dvloading_options_2','animatedgif', 'angus');
        $customimage = dvloading_get_option('dvloading_options_2','customimage','');
        $showskip = dvloading_get_option('dvloading_options_2','showskip','enable');
        $skiptext = dvloading_get_option('dvloading_options_2','skiptext',esc_html__( 'Click here to skip loading', 'dvloading'));
        $skipplacement = dvloading_get_option('dvloading_options_2','skipplacement','isgskiptopright');
        $showcounter = dvloading_get_option('dvloading_options_2','showcounter','enable');
        $counterplacement = dvloading_get_option('dvloading_options_2','counterplacement','isgcounterbottomright');
        ?>

        <div id="isg-page-loading" style="display:block;">
            <div id="isg-loading-table">
                <div id="isg-loading-cell">
                    <?php if (($animationstyle == 'text') || (empty($animationstyle))) { ?>
                    <div id="isg-loading-text" data-content="<?php echo esc_attr($titletext); ?>"><?php echo esc_html($titletext); ?></div>
                        <?php if (!empty($subtitletext)) { ?>
                            <div id="isg-loading-sub-text"><?php echo esc_html($subtitletext); ?></div> 
                        <?php }
                    } else {
                        if (empty($customimage)) { ?>
                        <div id="isg-loading-gif">
                            <img src="<?php echo esc_url(plugin_dir_url( __FILE__ ) . 'images/128/' . $animatedgif . '.gif' ); ?>" alt="<?php echo esc_attr($titletext); ?>" />
                        </div>
                        <?php } else { ?>
                        <div id="isg-loading-image">
                            <?php
                            if ($customimage) {
                                echo '<img src="' . $customimage . '" />';
                            }
                            ?>
                        </div>
                        <?php }
                    } ?>      
                </div>
            </div>
            <?php if ($barplacement != 'hide') { ?>
            <div id="isg-loading-bar" class="<?php echo esc_attr($barplacement); ?>"></div>
            <?php } ?>
            <?php if ($showskip == 'enable') { ?>
            <div id="isg-skip-text" class="<?php echo esc_attr($skipplacement); ?>">
                <div id="isg-skip-inner"><?php echo esc_html($skiptext); ?></div>
            </div>
            <?php } ?>
            <?php if ($showcounter == 'enable') { ?>
            <div id="isg-percentage" class="<?php echo esc_attr($counterplacement); ?>">
                <div id="isg-percentage-inner">
                    <span></span>%
                </div>
            </div>
            <?php } ?>
        </div>
<?php
    }
}

/**
 * Returns the main instance of dvloading.
 */
function DVloading_Class() {  
	return DVloading_Class::instance();
}
// Global for backwards compatibility.
$GLOBALS['DVloading_Class'] = DVloading_Class();