<?php
defined( 'ABSPATH' ) || exit;

class DVloadingSettings {
    /* The single instance of the class */
	protected static $_instance = null;

    /* Main Instance */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

    /* Constructor */
    public function __construct() {
        add_action( 'cmb2_admin_init', array($this, 'register_metabox') );
        add_action( 'admin_enqueue_scripts',array($this, 'colorpicker_labels'), 99 );
    }

    /**
    * Hook in and register a metabox to handle a plugin options page and adds a menu item.
    */
    public function register_metabox() {
        // GENERAL SETTINGS
        $args = array(
            'id'           => 'dvloading_options',
            'title'        => esc_html__('DV Loading', 'dvloading'),
            'object_types' => array( 'options-page' ),
            'option_key'   => 'dvloading_options',
            'tab_group'    => 'dvloading_options',
            'tab_title'    => esc_html__('General', 'dvloading')
        );
        
        // 'tab_group' property is supported in > 2.4.0.
        if ( version_compare( CMB2_VERSION, '2.4.0' ) ) {
            $args['display_cb'] = array($this, 'display_with_tabs');
        }
        
        $main_options = new_cmb2_box( $args );

        $main_options->add_field( array(
            'name' => esc_html__( 'Custom CSS', 'dvloading' ),
            'id' => 'custom_css',
            'type' => 'textarea_code',
            'attributes' => array(
                'data-codeeditor' => json_encode( array(
                    'codemirror' => array(
                        'mode' => 'css'
                    ),
                ) ),
            ),
        ) );

        $main_options->add_field(
            array(
                'name' => esc_html__( 'Animation Style', 'dvloading'),  
                'description' => esc_html__( 'Default animation style.', 'dvloading'),  
                'id' => 'animationstyle',
                'type' => 'radio_inline',
                'options' => array(
                    'text' => esc_html__( 'Loading Text', 'dvloading' ),
                    'image'   => esc_html__( 'Loading Image', 'dvloading' )
                ),
                'default' => 'text',
            )
        );

        $main_options->add_field(
            array(
                'name' => esc_html__( 'Transitions', 'dvloading'),  
                'description' => esc_html__( 'CSS3 page transitions.', 'dvloading'),  
                'id' => 'transition',
                'type' => 'radio_inline',
                'options' => array(
                    'enable' => esc_html__( 'Enable', 'dvloading' ),
                    'disable'   => esc_html__( 'Disable', 'dvloading' )
                ),
                'default' => 'enable',
            )
        );

        $main_options->add_field(
            array(
                'name' => esc_html__( 'Select Transition', 'dvloading'),
                'id' => 'pagetransitions',
                'type' => 'select',
                'attributes' => array(
                    'data-conditional-id' => 'transition',
                    'data-conditional-value' => 'enable'
                ),
                'options' => array('bounceOut' => 'bounceOut','bounceOutDown' => 'bounceOutDown','bounceOutLeft' => 'bounceOutLeft','bounceOutRight' => 'bounceOutRight','bounceOutUp' => 'bounceOutUp','fadeOut' => 'fadeOut','fadeOutDown' => 'fadeOutDown','fadeOutDownBig' => 'fadeOutDownBig','fadeOutLeft' => 'fadeOutLeft','fadeOutLeftBig' => 'fadeOutLeftBig','fadeOutRight' => 'fadeOutRight','fadeOutRightBig' => 'fadeOutRightBig','fadeOutUp' => 'fadeOutUp','fadeOutUpBig' => 'fadeOutUpBig','flipOutX' => 'flipOutX','flipOutY' => 'flipOutY','lightSpeedOut' => 'lightSpeedOut','rollOut' => 'rollOut','rotateOut' => 'rotateOut','rotateOutDownLeft' => 'rotateOutDownLeft','rotateOutDownRight' => 'rotateOutDownRight','rotateOutUpLeft' => 'rotateOutUpLeft','rotateOutUpRight' => 'rotateOutUpRight','zoomOut' => 'zoomOut','zoomOutDown' => 'zoomOutDown','zoomOutLeft' => 'zoomOutLeft','zoomOutRight' => 'zoomOutRight','zoomOutUp' => 'zoomOutUp','slideOutDown' => 'slideOutDown','slideOutLeft' => 'slideOutLeft','slideOutRight' => 'slideOutRight','slideOutUp' => 'slideOutUp'),
                'default' => 'bounceOut'
            )
        );

        $main_options->add_field( array(
            'name' => esc_html__( 'Background Color', 'dvloading' ),
            'id'   => 'bgcolor',
            'type' => 'colorpicker',
            'default' => '#1F2041',
            'options' => array(
                'alpha' => false
            )
        ) );

        $main_options->add_field(
            array(
                'name' => esc_html__( 'Where to Show the Loading Animation?', 'dvloading'),
                'id' => 'placement',
                'type' => 'select',
                'options' => array(
                    'allpages' => esc_html__( 'All Pages', 'dvloading' ),
                    'homepage' => esc_html__( 'Front Page', 'dvloading' ),
                    'posttype' => esc_html__( 'Select Post Type', 'dvloading' ),
                    'shortcodemode' => esc_html__( 'Use The Shortcode', 'dvloading' ),
                    'disable' => esc_html__( 'Disable Page Loading', 'dvloading' )
                ),
                'default' => 'allpages'
            )
        );

        $main_options->add_field(
            array(
                'name' => esc_html__( 'Shortcode', 'dvloading'),
                'id' => 'shortcodeoutput',
                'type' => 'textarea',
                'save_fields'  => false,
                'attributes' => array(
                    'readonly' => 'readonly'
                ),
                'attributes' => array(
                    'readonly' => 'readonly',
                    'data-conditional-id'    => 'placement',
                    'data-conditional-value' => 'shortcodemode',
                ),
                'default' => $this->get_shortcode()
            )
        );

        $main_options->add_field(
            array(
                'name' => esc_html__( 'Post Type(s)', 'dvloading'),
                'id' => 'posttypes',
                'type' => 'multicheck_inline',
                'options' => get_post_types(array('public' => true)),
                'default' => array('post', 'page'),
                'attributes' => array(
                    'data-conditional-id'    => 'placement',
                    'data-conditional-value' => 'posttype',
                ),
            )
        );

        $main_options->add_field(
            array(
                'name' => esc_html__( 'Include Archive Pages', 'dvloading'),  
                'description' => esc_html__( 'Category, Tag, other Taxonomy Term, custom post type archive, Author and Date-based pages are all types of Archives.', 'dvloading'),  
                'id' => 'archive',
                'type' => 'radio_inline',
                'options' => array(
                    'enable' => esc_html__( 'Enable', 'dvloading' ),
                    'disable'   => esc_html__( 'Disable', 'dvloading' )
                ),
                'attributes' => array(
                    'data-conditional-id'    => 'placement',
                    'data-conditional-value' => 'posttype',
                ),
                'default' => 'enable'
            )
        );

        $main_options->add_field(
            array(
                'name' => esc_html__( 'Test Mode', 'dvloading'),  
                'description' => esc_html__( 'If you enable test mode, page loading container will not disappear after page loading. It may be useful to test the layout, animation etc.', 'dvloading'),  
                'id' => 'testmode',
                'type' => 'radio_inline',
                'options' => array(
                    'enable' => esc_html__( 'Enable', 'dvloading' ),
                    'disable'   => esc_html__( 'Disable', 'dvloading' )
                ),
                'default' => 'disable',
            )
        );
        
        // TEXT SETTINGS
        $args = array(
            'id'           => 'dvloading_options_1',
            'title'        => esc_html__('DV Loading', 'dvloading'),
            'menu_title'   => esc_html__('Loading Text', 'dvloading'),
            'object_types' => array( 'options-page' ),
            'option_key'   => 'dvloading_options_1',
            'parent_slug'  => 'dvloading_options',
            'tab_group'    => 'dvloading_options',
            'tab_title'    => esc_html__('Loading Text', 'dvloading'),
        );
        
        // 'tab_group' property is supported in > 2.4.0.
        if ( version_compare( CMB2_VERSION, '2.4.0' ) ) {
            $args['display_cb'] = array($this, 'display_with_tabs');
        }
        
        $options_1 = new_cmb2_box( $args );

        $options_1->add_field(
            array(
                'name' => esc_html__( 'Font Family', 'dvloading'), 
                'id' => 'font_family',
                'type' => 'select',
                'options' => dvloading_get_fonts(),
                'default' => 'default',
            )
        );

        $options_1->add_field(
            array(
                'name' => esc_html__( 'Title', 'dvloading'), 
                'id' => 'titletext',
                'type' => 'text',
                'default' => esc_html__( 'Loading...', 'dvloading')
            )
        );

        $options_1->add_field(
            array(
                'name' => esc_html__( 'Sub Title', 'dvloading'), 
                'id' => 'subtitletext',
                'type' => 'text',
                'default' => ''
            )
        );

        $options_1->add_field(
            array(
                'name' => esc_html__( 'Mobile Devices', 'dvloading'),  
                'description' => esc_html__( 'Enable or disable text animation on mobile devices.', 'dvloading'),  
                'id' => 'disabletextmobile',
                'type' => 'radio_inline',
                'options' => array(
                    'enable' => esc_html__( 'Enable', 'dvloading' ),
                    'disable'   => esc_html__( 'Disable', 'dvloading' )
                ),
                'default' => 'enable',
            )
        );

        $options_1->add_field( array(
            'name' => esc_html__( 'Title Font Size', 'dvloading' ),
            'type' => 'title',
            'id'   => 'title_font_sizes_subtitle'
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Line Height', 'dvloading' ),
            'id'   => 'titlelineheight',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
                'step' => '0.1'
            ),
            'default' => 1.3,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'PC', 'dvloading' ),
            'id'   => 'titlefontsize',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 90,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Laptop', 'dvloading' ),
            'description' => esc_html__( 'Below 1200px width (px)', 'dvloading'), 
            'id'   => 'desktop',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 82,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Tablet Landscape', 'dvloading' ),
            'description' => esc_html__( 'Below 1024px width (px)', 'dvloading'), 
            'id'   => 'tabletlandscape',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 72,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Tablet Portrait', 'dvloading' ),
            'description' => esc_html__( 'Below 768px width (px)', 'dvloading'), 
            'id'   => 'tabletportrait',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 64,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Phone Landscape', 'dvloading' ),
            'description' => esc_html__( 'Below 640px width (px)', 'dvloading'), 
            'id'   => 'phonelandscape',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 56,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Phone Portrait', 'dvloading' ),
            'description' => esc_html__( 'Below 480px width (px)', 'dvloading'), 
            'id'   => 'phoneportrait',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 48,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Small Phones', 'dvloading' ),
            'description' => esc_html__( 'Below 340px width (px)', 'dvloading'), 
            'id'   => 'smalldevices',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 40,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Sub Title Font Size', 'dvloading' ),
            'type' => 'title',
            'id'   => 'subtitle_font_sizes_subtitle'
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Line Height', 'dvloading' ),
            'id'   => 'subtitlelineheight',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 1,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'PC', 'dvloading' ),
            'id'   => 'subtitlefontsize',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 40,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Laptop', 'dvloading' ),
            'description' => esc_html__( 'Below 1200px width (px)', 'dvloading'), 
            'id'   => 'subdesktop',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 36,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Tablet Landscape', 'dvloading' ),
            'description' => esc_html__( 'Below 1024px width (px)', 'dvloading'), 
            'id'   => 'subtabletlandscape',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 30,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Tablet Portrait', 'dvloading' ),
            'description' => esc_html__( 'Below 768px width (px)', 'dvloading'), 
            'id'   => 'subtabletportrait',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 26,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Phone Landscape', 'dvloading' ),
            'description' => esc_html__( 'Below 640px width (px)', 'dvloading'), 
            'id'   => 'subphonelandscape',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 24,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Phone Portrait', 'dvloading' ),
            'description' => esc_html__( 'Below 480px width (px)', 'dvloading'), 
            'id'   => 'subphoneportrait',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 20,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Small Phones', 'dvloading' ),
            'description' => esc_html__( 'Below 340px width (px)', 'dvloading'), 
            'id'   => 'subsmalldevices',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 18,
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Title & Sub Title Colors', 'dvloading' ),
            'type' => 'title',
            'id'   => 'text_colors_subtitle'
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Title', 'dvloading' ),
            'id'   => 'titlecolor',
            'type' => 'colorpicker',
            'default' => 'rgba(255, 255, 255, 0.1)',
            'options' => array(
                'alpha' => true
            )
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Loaded Title', 'dvloading' ),
            'id'   => 'loadedtitlecolor',
            'type' => 'colorpicker',
            'default' => '#ffffff',
            'options' => array(
                'alpha' => true
            )
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Sub Title', 'dvloading' ),
            'id'   => 'subtitlecolor',
            'type' => 'colorpicker',
            'default' => 'rgba(255, 255, 255, 0.1)',
            'options' => array(
                'alpha' => true
            )
        ) );

        $options_1->add_field( array(
            'name' => esc_html__( 'Loaded Sub Title', 'dvloading' ),
            'id'   => 'loadedsubtitlecolor',
            'type' => 'colorpicker',
            'default' => 'rgba(255, 255, 255, 0.3)',
            'options' => array(
                'alpha' => true
            )
        ) );
        
        // IMAGE SETTINGS
        $args = array(
            'id'           => 'dvloading_options_2',
            'title'        => esc_html__('DV Loading', 'dvloading'),
            'menu_title'   => esc_html__('Elements', 'dvloading'),
            'object_types' => array( 'options-page' ),
            'option_key'   => 'dvloading_options_2',
            'parent_slug'  => 'dvloading_options',
            'tab_group'    => 'dvloading_options',
            'tab_title'    => esc_html__('Elements', 'dvloading'),
        );
        
        // 'tab_group' property is supported in > 2.4.0.
        if ( version_compare( CMB2_VERSION, '2.4.0' ) ) {
            $args['display_cb'] = array($this, 'display_with_tabs');
        }
        
        $options_2 = new_cmb2_box( $args );

        $options_2->add_field( array(
            'name' => esc_html__( 'Image', 'dvloading' ),
            'type' => 'title',
            'id'   => 'image_subtitle',
            'classes' => array('open-by-default')
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'GIF Animation', 'dvloading' ),
            'id'   => 'animatedgif',
            'type' => 'tm_radio_image',
            'options'  => array(
                'angus' => 'angus',
                'bill' => 'bill',
                'forrest' => 'forrest',
                'frederic' => 'frederic',
                'gordon' => 'gordon',
                'john' => 'john',
                'leonardo' => 'leonardo',
                'marty' => 'marty',
                'nicolas' => 'nicolas',
                'randi' => 'randi',
                'sadi' => 'sadi',
                'zooey' => 'zooey',
                'preloader1' => 'preloader1',
                'preloader2' => 'preloader2',
                'preloader3' => 'preloader3',
                'preloader4' => 'preloader4',
                'preloader5' => 'preloader5',
                'preloader6' => 'preloader6',
                'preloader7' => 'preloader7',
                'preloader8' => 'preloader8',
                'preloader9' => 'preloader9',
                'preloader10' => 'preloader10',
                'preloader11' => 'preloader11',
                'preloader12' => 'preloader12',
                'preloader13' => 'preloader13',
                'preloader14' => 'preloader14',
                'preloader15' => 'preloader15',
                'preloader16' => 'preloader16',
                'preloader17' => 'preloader17',
            ),
            'images_path'      => plugin_dir_url( __FILE__ ) . 'images/32/',
            'images'           => array(
                'angus' => 'angus.gif',
                'bill' => 'bill.gif',
                'forrest' => 'forrest.gif',
                'frederic' => 'frederic.gif',
                'gordon' => 'gordon.gif',
                'john' => 'john.gif',
                'leonardo' => 'leonardo.gif',
                'marty' => 'marty.gif',
                'nicolas' => 'nicolas.gif',
                'randi' => 'randi.gif',
                'sadi' => 'sadi.gif',
                'zooey' => 'zooey.gif',
                'preloader1' => 'preloader1.gif',
                'preloader2' => 'preloader2.gif',
                'preloader3' => 'preloader3.gif',
                'preloader4' => 'preloader4.gif',
                'preloader5' => 'preloader5.gif',
                'preloader6' => 'preloader6.gif',
                'preloader7' => 'preloader7.gif',
                'preloader8' => 'preloader8.gif',
                'preloader9' => 'preloader9.gif',
                'preloader10' => 'preloader10.gif',
                'preloader11' => 'preloader11.gif',
                'preloader12' => 'preloader12.gif',
                'preloader13' => 'preloader13.gif',
                'preloader14' => 'preloader14.gif',
                'preloader15' => 'preloader15.gif',
                'preloader16' => 'preloader16.gif',
                'preloader17' => 'preloader17.gif',
            ),
            'default' => 'angus'
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'GIF Size', 'dvloading' ),
            'id'   => 'gifsize',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 64,
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Custom Image', 'dvloading' ),
            'id'   => 'customimage',
            'type' => 'file',
            'query_args' => array(
                'type' => array(
                    'image/gif',
                    'image/jpeg',
                    'image/png',
                ),
            ),
            'preview_size' => 'medium',
        ) );

        $options_2->add_field(
            array(
                'name' => esc_html__( 'Rounding', 'dvloading'),  
                'id' => 'rounding',
                'type' => 'select',
                'options' => array(
                    0 => esc_html__( 'None', 'dvloading' ),
                    10 => esc_html__( 'Slightly Rounded', 'dvloading' ),
                    25 => esc_html__( 'Very Rounded', 'dvloading' ),
                    100 => esc_html__( 'Completely Rounded', 'dvloading' ),
                ),
                'default' => 0,
            )
        );

        $options_2->add_field(
            array(
                'name' => esc_html__( 'Image Animation', 'dvloading'),  
                'id' => 'imageanimation',
                'type' => 'select',
                'options' => array(
                    'disable' => esc_html__( 'None', 'dvloading' ),
                    'rubberBand' => esc_html__( 'Rubber Band', 'dvloading' ),
                    'pulse' => esc_html__( 'Pulse', 'dvloading' ),
                    'jello' => esc_html__( 'Jello', 'dvloading' ),
                ),
                'default' => 'disable',
            )
        );

        $options_2->add_field(
            array(
                'name' => esc_html__( 'Animation Duration', 'dvloading'),  
                'id' => 'imageduration',
                'type' => 'select',
                'options' => array(
                    'fast' => esc_html__( 'Fast', 'dvloading' ),
                    'normal' => esc_html__( 'Normal', 'dvloading' ),
                    'slow' => esc_html__( 'Slow', 'dvloading' ),
                ),
                'default' => 'normal',
            )
        );

        $options_2->add_field( array(
            'name' => esc_html__( 'Bar', 'dvloading' ),
            'type' => 'title',
            'id'   => 'bar_subtitle'
        ) );

        $options_2->add_field(
            array(
                'name' => esc_html__( 'Placement', 'dvloading'),  
                'id' => 'barplacement',
                'type' => 'select',
                'options' => array(
                    'isgbottombar' => esc_html__( 'Bottom', 'dvloading' ),
                    'isgtopbar' => esc_html__( 'Top', 'dvloading' ),
                    'hide' => esc_html__( 'Hide', 'dvloading' ),
                ),
                'default' => 'isgbottombar',
            )
        );

        $options_2->add_field( array(
            'name' => esc_html__( 'Height (px)', 'dvloading' ),
            'id'   => 'barheight',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 3,
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Color', 'dvloading' ),
            'id'   => 'barcolor',
            'type' => 'colorpicker',
            'default' => 'rgba(255, 255, 255, 0.1)',
            'options' => array(
                'alpha' => true
            )
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Loaded Color', 'dvloading' ),
            'id'   => 'loadedbarcolor',
            'type' => 'colorpicker',
            'default' => '#ffffff',
            'options' => array(
                'alpha' => true
            )
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Percentage Counter', 'dvloading' ),
            'type' => 'title',
            'id'   => 'counter_subtitle'
        ) );

        $options_2->add_field(
            array(
                'name' => esc_html__( 'Percentage Counter', 'dvloading'),  
                'id' => 'showcounter',
                'type' => 'radio_inline',
                'options' => array(
                    'enable' => esc_html__( 'Enable', 'dvloading' ),
                    'disable' => esc_html__( 'Disable', 'dvloading' ),
                ),
                'default' => 'enable',
            )
        );

        $options_2->add_field(
            array(
                'name' => esc_html__( 'Placement', 'dvloading'),  
                'description' => esc_html__( 'The alignment of the percentage counter within the screen.', 'dvloading'),  
                'id' => 'counterplacement',
                'type' => 'select',
                'options' => array(
                    'isgcounterbottomright' => esc_html__( 'Bottom Right', 'dvloading' ),
                    'isgcounterbottomleft' => esc_html__( 'Bottom Left', 'dvloading' ),
                    'isgcounterbottomcenter' => esc_html__( 'Bottom Center', 'dvloading' ),
                    'isgcountertopright' => esc_html__( 'Top Right', 'dvloading' ),
                    'isgcountertopleft' => esc_html__( 'Top Left', 'dvloading' ),
                    'isgcountertopcenter' => esc_html__( 'Top Center', 'dvloading' ),
                ),
                'default' => 'isgcounterbottomright',
            )
        );

        $options_2->add_field( array(
            'name' => esc_html__( 'Margin Top & Bottom', 'dvloading' ),
            'description' => esc_html__( 'You can use this setting to push or pull your counter up or down (px).', 'dvloading'),
            'id'   => 'countertopbottom',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 20,
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Margin Left & Right', 'dvloading' ),
            'description' => esc_html__( 'You can use this setting to push or pull your counter left or right (px).', 'dvloading'),
            'id'   => 'counterleftright',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 20,
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Text Color', 'dvloading' ),
            'id'   => 'countercolor',
            'type' => 'colorpicker',
            'default' => '#ffffff',
            'options' => array(
                'alpha' => true
            )
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Font Size', 'dvloading' ),
            'description' => esc_html__( 'PCs, Laptops (px).', 'dvloading'),
            'id'   => 'counterfontsize',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 40,
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Font Size (Tablets)', 'dvloading' ),
            'description' => esc_html__( 'Below 1024px width (px).', 'dvloading'),
            'id'   => 'countertabletsize',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 30,
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Font Size (Phones)', 'dvloading' ),
            'description' => esc_html__( 'Below 480px width (px).', 'dvloading'),
            'id'   => 'counterphonesize',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 20,
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Skip Loading', 'dvloading' ),
            'type' => 'title',
            'id'   => 'skip_subtitle'
        ) );

        $options_2->add_field(
            array(
                'name' => esc_html__( 'Display Skip Loading Text', 'dvloading'),  
                'id' => 'showskip',
                'type' => 'radio_inline',
                'options' => array(
                    'enable' => esc_html__( 'Enable', 'dvloading' ),
                    'disable' => esc_html__( 'Disable', 'dvloading' ),
                ),
                'default' => 'enable',
            )
        );

        $options_2->add_field(
            array(
                'name' => esc_html__( 'Text', 'dvloading'),  
                'id' => 'skiptext',
                'type' => 'text',
                'default' => esc_html__( 'Click here to skip loading', 'dvloading')
            )
        );

        $options_2->add_field( array(
            'name' => esc_html__( 'Display delay', 'dvloading' ),
            'description' => esc_html__( 'Indicate the delay in millisecond (1 second=1000 milliseconds) before the skip text appears.', 'dvloading'),
            'id'   => 'skipdelay',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 1000,
        ) );

        $options_2->add_field(
            array(
                'name' => esc_html__( 'Placement', 'dvloading'),  
                'description' => esc_html__( 'The alignment of the text within the screen.', 'dvloading'),  
                'id' => 'skipplacement',
                'type' => 'select',
                'options' => array(
                    'isgskiptopright' => esc_html__( 'Top Right', 'dvloading' ),
                    'isgskiptopleft' => esc_html__( 'Top Left', 'dvloading' ),
                    'isgskiptopcenter' => esc_html__( 'Top Center', 'dvloading' ),
                    'isgskipbottomright' => esc_html__( 'Bottom Right', 'dvloading' ),
                    'isgskipbottomleft' => esc_html__( 'Bottom Left', 'dvloading' ),
                    'isgskipbottomcenter' => esc_html__( 'Bottom Center', 'dvloading' ),
                ),
                'default' => 'isgskiptopright',
            )
        );

        $options_2->add_field( array(
            'name' => esc_html__( 'Margin Top & Bottom', 'dvloading' ),
            'description' => esc_html__( 'You can use this setting to push or pull your text up or down (px).', 'dvloading'),
            'id'   => 'skiptopbottom',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 20,
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Margin Left & Right', 'dvloading' ),
            'description' => esc_html__( 'You can use this setting to push or pull your counter text or right (px).', 'dvloading'),
            'id'   => 'skipleftright',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 20,
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Color', 'dvloading' ),
            'id'   => 'skipcolor',
            'type' => 'colorpicker',
            'default' => '#ffffff',
            'options' => array(
                'alpha' => true
            )
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Font Size', 'dvloading' ),
            'description' => esc_html__( 'PCs, Laptops (px).', 'dvloading'),
            'id'   => 'skipfontsize',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 16,
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Font Size (Tablets)', 'dvloading' ),
            'description' => esc_html__( 'Below 1024px width (px).', 'dvloading'),
            'id'   => 'skiptabletsize',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 15,
        ) );

        $options_2->add_field( array(
            'name' => esc_html__( 'Font Size (Phones)', 'dvloading' ),
            'description' => esc_html__( 'Below 480px width (px).', 'dvloading'),
            'id'   => 'skipphonesize',
            'type' => 'text',
            'attributes' => array(
                'type' => 'number',
                'pattern' => '\d*',
            ),
            'default' => 14,
        ) );
        
    }

    /**
    * Get Shortcode
    */
    public function get_shortcode() {
        $pagetransition = dvloading_get_option('dvloading_options','pagetransitions','bounceOut' );      
        $titletext = dvloading_get_option('dvloading_options_1','titletext',esc_html__( 'Loading...', 'dvloading'));
        $subtitletext = dvloading_get_option('dvloading_options_1','subtitletext','');
        $barplacement = dvloading_get_option('dvloading_options_2','barplacement','isgbottombar');
        $animationstyle = dvloading_get_option('dvloading_options','animationstyle','text');
        $animatedgif = dvloading_get_option('dvloading_options_2','animatedgif', 'angus');
        $gifsize = dvloading_get_option('dvloading_options_2','gifsize',64);
        $customimage = dvloading_get_option('dvloading_options_2','customimage','');
        $imageanimation = dvloading_get_option('dvloading_options_2','imageanimation', 'enable' );
        $imageduration = dvloading_get_option('dvloading_options_2','imageduration','normal' );
        $showskip = dvloading_get_option('dvloading_options_2','showskip','enable' );
        $skiptext = dvloading_get_option('dvloading_options_2','skiptext',esc_html__( 'Click here to skip loading', 'dvloading'));
        $skipplacement = dvloading_get_option('dvloading_options_2','skipplacement','isgskiptopright');
        $showcounter = dvloading_get_option('dvloading_options_2','showcounter', 'enable' );
        $counterplacement = dvloading_get_option('dvloading_options_2','counterplacement','isgcounterbottomright');
        $bgcolor = dvloading_get_option('dvloading_options','bgcolor', '#1F2041');
        $titlecolor = dvloading_get_option('dvloading_options_1','titlecolor','rgba(255, 255, 255, 0.1)');
        $loadedtitlecolor = dvloading_get_option('dvloading_options_1','loadedtitlecolor','#ffffff');
        $subtitlecolor = dvloading_get_option('dvloading_options_1','subtitlecolor','rgba(255, 255, 255, 0.1)');
        $loadedsubtitlecolor = dvloading_get_option('dvloading_options_1','loadedsubtitlecolor','rgba(255, 255, 255, 0.3)');
        $barcolor = dvloading_get_option('dvloading_options_2','barcolor','rgba(255, 255, 255, 0.1)');
        $loadedbarcolor = dvloading_get_option('dvloading_options_2','loadedbarcolor','#ffffff');
        $barheight = dvloading_get_option('dvloading_options_2','barheight',3);
        $rounding = dvloading_get_option('dvloading_options_2','rounding', '0');
        $skipcolor = dvloading_get_option('dvloading_options_2','skipcolor','#ffffff');
        $countercolor = dvloading_get_option('dvloading_options_2','countercolor','#ffffff');
        $skipdelay = dvloading_get_option('dvloading_options_2','skipdelay', 1000 );

        $output = '[dvloading animationstyle="' . $animationstyle .'" pagetransition="' . $pagetransition .'" bgcolor="' . $bgcolor .'" titletext="' . $titletext .'" titlecolor="' . $titlecolor .'" loadedtitlecolor="' . $loadedtitlecolor .'" subtitletext="' . $subtitletext .'" subtitlecolor="' . $subtitlecolor .'" animatedgif="' . $animatedgif .'" gifsize="' . $gifsize .'" customimage="' . $customimage .'" imageanimation="' . $imageanimation .'" imageduration="' . $imageduration .'" loadedsubtitlecolor="' . $loadedsubtitlecolor .'" barplacement="' . $barplacement .'" barcolor="' . $barcolor .'" loadedbarcolor="' . $loadedbarcolor .'" barheight="' . $barheight .'" rounding="' . $rounding .'" showskip="' . $showskip .'" skiptext="' . $skiptext .'" skipplacement="' . $skipplacement .'" skipcolor="' . $skipcolor .'" skipdelay="' . $skipdelay .'" showcounter="' . $showcounter .'" counterplacement="' . $counterplacement .'" countercolor="' . $countercolor .'"]';

        return $output;
    }

    /**
    * Gets navigation tabs array for CMB2 options pages which share the given
    * display_cb param.
    *
    * @param CMB2_Options_Hookup $cmb_options The CMB2_Options_Hookup object.
    *
    * @return array Array of tab information.
    */
    public function page_tabs( $cmb_options ) {
        $tab_group = $cmb_options->cmb->prop( 'tab_group' );
        $tabs      = array();
        
        foreach ( CMB2_Boxes::get_all() as $cmb_id => $cmb ) {
            if ( $tab_group === $cmb->prop( 'tab_group' ) ) {
                $tabs[ $cmb->options_page_keys()[0] ] = $cmb->prop( 'tab_title' )
                    ? $cmb->prop( 'tab_title' )
                    : $cmb->prop( 'title' );
            }
        }
        
        return $tabs;
    }

    /**
    * A CMB2 options-page display callback override which adds tab navigation among
    * CMB2 options pages which share this same display callback.
    *
    * @param CMB2_Options_Hookup $cmb_options The CMB2_Options_Hookup object.
    */
    public function display_with_tabs( $cmb_options ) {
        $tabs = $this->page_tabs( $cmb_options );
        ?>
        <div class="wrap cmb2-options-page option-<?php echo esc_attr($cmb_options->option_key); ?>">
            <?php if ( get_admin_page_title() ) : ?>
                <h2><?php echo wp_kses_post( get_admin_page_title() ); ?></h2>
            <?php endif; ?>
            <h2 class="nav-tab-wrapper">
                <?php foreach ( $tabs as $option_key => $tab_title ) : ?>
                    <a class="nav-tab<?php if ( isset( $_GET['page'] ) && $option_key === $_GET['page'] ) : ?> nav-tab-active<?php endif; ?>" href="<?php menu_page_url( $option_key ); ?>"><?php echo wp_kses_post( $tab_title ); ?></a>
                <?php endforeach; ?>
            </h2>
            <form class="cmb-form" action="<?php echo esc_url( admin_url( 'admin-post.php' ) ); ?>" method="POST" id="<?php echo esc_attr($cmb_options->cmb->cmb_id); ?>" enctype="multipart/form-data" encoding="multipart/form-data">
                <input type="hidden" name="action" value="<?php echo esc_attr( $cmb_options->option_key ); ?>">
                <?php $cmb_options->options_page_metabox(); ?>
                <?php submit_button( esc_attr( $cmb_options->cmb->prop( 'save_button' ) ), 'primary', 'submit-cmb' ); ?>
            </form>
        </div>
    <?php
    }

    /**
    * Colorpicker Labels
    */
    public function colorpicker_labels( $hook ) {
        global $wp_version;
        if( version_compare( $wp_version, '5.4.2' , '>=' ) ) {
            wp_localize_script(
            'wp-color-picker',
            'wpColorPickerL10n',
            array(
                'clear'            => esc_html__( 'Clear', 'dvloading' ),
                'clearAriaLabel'   => esc_html__( 'Clear color', 'dvloading' ),
                'defaultString'    => esc_html__( 'Default', 'dvloading' ),
                'defaultAriaLabel' => esc_html__( 'Select default color', 'dvloading' ),
                'pick'             => esc_html__( 'Select Color', 'dvloading' ),
                'defaultLabel'     => esc_html__( 'Color value', 'dvloading' )
            )
            );
        }
    }

}

/**
 * Returns the main instance of dvloading.
 */
function DVloadingSettings() {  
	return DVloadingSettings::instance();
}
// Global for backwards compatibility.
$GLOBALS['DVloadingSettings'] = DVloadingSettings();


/**
* Custom Get option
*/

function dvloading_get_option( $tab = 'dvloading_options', $key = '', $default = false ) {
	if ( function_exists( 'cmb2_get_option' ) ) {
		return cmb2_get_option( $tab, $key, $default );
	}
	$opts = get_option( $tab, $default );
	$val = $default;
	if ( 'all' == $key ) {
		$val = $opts;
	} elseif ( is_array( $opts ) && array_key_exists( $key, $opts ) && false !== $opts[ $key ] ) {
		$val = $opts[ $key ];
	}
	return $val;
}