<?php
defined( 'ABSPATH' ) || exit;

class DVloadingShortcode {
    /* The single instance of the class */
	protected static $_instance = null;

    /* Check if scripts are required */
    protected static $add_scripts;

    /* Main Instance */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

    /* Constructor */
    public function __construct() {
        add_action('wp_head',array($this, 'head') , 1);
        add_action('wp_footer',array($this, 'enqueue_scripts'));
		add_shortcode('dvloading', array($this, 'shortcode'));
        add_filter("the_content", array($this, 'content_filter'));
        add_filter("widget_text", array($this, 'content_filter'), 9);
    }

    /* Content Filter */
    public function content_filter($content) {
        // array of custom shortcodes requiring the fix 
        $block = join("|",array("dvteam","dvteamfilter","dvteamcarousel","dvmember","dvthumbnails","dvskills","dvskill","dvcv"));
        // opening tag
        $rep = preg_replace("/(<p>)?\[($block)(\s[^\]]+)?\](<\/p>|<br \/>)?/","[$2$3]",$content);       
        // closing tag
        $rep = preg_replace("/(<p>)?\[\/($block)](<\/p>|<br \/>)?/","[/$2]",$rep);
        return $rep;
    }

    /* Add required scripts to hide everything before print to avoid blink */
    public function head() {
        ?>
        <script type="text/javascript">document.documentElement.className += ' isg-page-loading-fix-html ';</script>
        <style type="text/css">html.isg-page-loading-fix-html * {visibility: hidden;}html.isg-page-loading-fix-html #isg-page-loading {visibility: visible;}</style>
    <?php }

    // Dv Loading Shortcode
    public function shortcode($atts) {
        // Load the scripts
        self::$add_scripts = true;

        $custom_css = dvloading_get_option('dvloading_options','custom_css', '');
        $fontfamily = dvloading_get_option('dvloading_options_1','font_family','default');
        $titlelineheight = dvloading_get_option('dvloading_options_1','titlelineheight', '1.3');
        $subtitlelineheight = dvloading_get_option('dvloading_options_1','subtitlelineheight', 1);
        $titlefontsize = dvloading_get_option('dvloading_options_1','titlefontsize', 90);
        $subtitlefontsize = dvloading_get_option('dvloading_options_1','subtitlefontsize', 40);
        $desktop = dvloading_get_option('dvloading_options_1','desktop', 82);
        $tabletlandscape = dvloading_get_option('dvloading_options_1','tabletlandscape', 72);
        $tabletportrait = dvloading_get_option('dvloading_options_1','tabletportrait', 64);
        $phonelandscape = dvloading_get_option('dvloading_options_1','phonelandscape', 56);
        $phoneportrait = dvloading_get_option('dvloading_options_1','phoneportrait', 48);
        $smalldevices = dvloading_get_option('dvloading_options_1','smalldevices',40);
        $subdesktop = dvloading_get_option('dvloading_options_1','subdesktop', 36);
        $subtabletlandscape = dvloading_get_option('dvloading_options_1','subtabletlandscape',30);
        $subtabletportrait = dvloading_get_option('dvloading_options_1','subtabletportrait',26);
        $subphonelandscape = dvloading_get_option('dvloading_options_1','subphonelandscape',24);
        $subphoneportrait = dvloading_get_option('dvloading_options_1','subphoneportrait',20);
        $subsmalldevices = dvloading_get_option('dvloading_options_1','subsmalldevices',18);
        $disabletextmobile = dvloading_get_option('dvloading_options_1','disabletextmobile', 'enable');    
        $skipfontsize = dvloading_get_option('dvloading_options_2','skipfontsize', 16);
        $skiptabletsize = dvloading_get_option('dvloading_options_2','skiptabletsize',15);
        $skipphonesize = dvloading_get_option('dvloading_options_2','skipphonesize',14);   
        $skipleftright = dvloading_get_option('dvloading_options_2','skipleftright', 20);
        $skiptopbottom = dvloading_get_option('dvloading_options_2','skiptopbottom',20);
        $counterfontsize = dvloading_get_option('dvloading_options_2','counterfontsize',40);
        $countertabletsize = dvloading_get_option('dvloading_options_2','countertabletsize',30);
        $counterphonesize = dvloading_get_option('dvloading_options_2','counterphonesize',20);   
        $counterleftright = dvloading_get_option('dvloading_options_2','counterleftright',20);
        $countertopbottom = dvloading_get_option('dvloading_options_2','countertopbottom',20);
        $barcolor = dvloading_get_option('dvloading_options_2','barcolor','rgba(255, 255, 255, 0.1)');

        $testmode = dvloading_get_option('dvloading_options','testmode', 'disable');
        $transition = dvloading_get_option('dvloading_options','transition', 'enable' );

        extract(shortcode_atts(array(
            "animationstyle" => 'animationstyle',
            "bgcolor" => 'bgcolor',
            "pagetransition" => 'pagetransition',
            "titletext" => 'titletext',
            "titlecolor" => 'titlecolor',
            "loadedtitlecolor" => 'loadedtitlecolor',
            "subtitletext" => 'subtitletext',
            "subtitlecolor" => 'subtitlecolor',
            "animatedgif" => 'animatedgif',
            "gifsize" => 'gifsize',
            "customimage" => 'customimage',
            "imageanimation" => 'imageanimation',
            "imageduration" => 'imageduration',
            "barplacement" => 'barplacement',
            "loadedsubtitlecolor" => 'loadedsubtitlecolor',
            "loadedbarcolor" => 'loadedbarcolor',
            "barheight" => 'barheight',
            "rounding" => 'rounding',
            "showskip" => 'showskip',
            "skiptext" => 'skiptext',
            "skipplacement" => 'skipplacement',
            "skipcolor" => 'skipcolor',
            "skipdelay" => 'skipdelay',
            "showcounter" => 'showcounter',
            "counterplacement" => 'counterplacement',
            "countercolor" => 'countercolor'
        ), $atts));

        // Custom Styles
        $inline_style = '';

        if ($fontfamily != 'default') {
            $inline_style .= '#isg-page-loading,#isg-loading-text,#isg-loading-sub-text, #isg-skip-inner,#isg-percentage-inner {font-family:' . $fontfamily . '}';
        }

        $inline_style .= '#isg-loading-gif img,#isg-loading-image img {width:' . $gifsize . 'px}';
        $inline_style .= '#isg-page-loading #isg-loading-text {font-size:' . $titlefontsize . 'px}';
        $inline_style .= '#isg-page-loading #isg-loading-sub-text {font-size:' . $subtitlefontsize . 'px}';
        $inline_style .= '#isg-loading-text {line-height:' . $titlelineheight . '}';
        $inline_style .= '#isg-skip-inner {font-size:' . $skipfontsize . 'px}';
        $inline_style .= '#isg-skip-inner {margin:' . $skiptopbottom . 'px ' . $skipleftright . 'px}';
        $inline_style .= '#isg-loading-sub-text {line-height:' . $subtitlelineheight . '}';
        $inline_style .= '#isg-percentage-inner {font-size:' . $counterfontsize . 'px}';
        $inline_style .= '#isg-percentage-inner {margin:' . $countertopbottom . 'px ' . $counterleftright . 'px}';
        $inline_style .= '@media only screen and (max-width: 1200px) {#isg-page-loading #isg-loading-text {font-size:' . $desktop . 'px}#isg-page-loading #isg-loading-sub-text {font-size:' . $subdesktop . 'px}}';
        $inline_style .= '@media only screen and (max-width: 1024px) {#isg-page-loading #isg-loading-text {font-size:' . $tabletlandscape . 'px}#isg-page-loading #isg-loading-sub-text {font-size:' . $subtabletlandscape . 'px}#isg-skip-inner {font-size:' . $skiptabletsize . 'px}#isg-percentage-inner {font-size:' . $countertabletsize . 'px}}';
        if ($disabletextmobile == 'enable') {
            $inline_style .= '@media only screen and (max-width: 1024px) {#isg-loading-text:before {width: 100% !important;}}';
        }
        $inline_style .= '@media only screen and (max-width: 768px) {#isg-page-loading #isg-loading-text {font-size:' . $tabletportrait . 'px}#isg-page-loading #isg-loading-sub-text {font-size:' . $subtabletportrait . 'px}}';
        $inline_style .= '@media only screen and (max-width: 640px) {#isg-page-loading #isg-loading-text {font-size:' . $phonelandscape . 'px}#isg-page-loading #isg-loading-sub-text {font-size:' . $subphonelandscape . 'px}}';
        $inline_style .= '@media only screen and (max-width: 480px) {#isg-page-loading #isg-loading-text {font-size:' . $phoneportrait . 'px}#isg-page-loading #isg-loading-sub-text {font-size:' . $subphoneportrait . 'px}#isg-skip-inner {font-size:' . $skipphonesize . 'px}#isg-percentage-inner {font-size:' . $counterphonesize . 'px}}';
        $inline_style .= '@media only screen and (max-width: 340px) {#isg-page-loading #isg-loading-text {font-size:' . $smalldevices . 'px}#isg-page-loading #isg-loading-sub-text {font-size:' . $subsmalldevices . 'px}}';

        $inline_style .= '#isg-page-loading,html.isg-page-loading-fix-html {background-color:' . $bgcolor . '}';
        $inline_style .= '#isg-loading-text {color:' . $titlecolor . '}';
        $inline_style .= '#isg-loading-text:before {color:' . $loadedtitlecolor . '}';
        $inline_style .= '#isg-loading-sub-text {color:' . $subtitlecolor . '}';
        $inline_style .= '#isg-loading-sub-text.loaded-subtitle {color:' . $loadedsubtitlecolor . '}';
        $inline_style .= '#isg-loading-bar {background:' . $barcolor . '}';
        $inline_style .= '#isg-loading-bar:before {background:' . $loadedbarcolor . '}';
        $inline_style .= '#isg-loading-bar,#isg-loading-bar:before {height:' . $barheight . 'px}';
        $inline_style .= '#isg-loading-gif img,#isg-loading-image img {border-radius:' . $rounding . '%}';
        $inline_style .= '#isg-skip-inner {color:' . $skipcolor . '}';
        $inline_style .= '#isg-percentage-inner {color:' . $countercolor . '}';

        if (!empty($custom_css)) {
            $inline_style .= $custom_css;
        }

        wp_enqueue_style('dvloading_styles', plugin_dir_url( __FILE__ ) . 'css/style.css', true, '1.0');
        wp_add_inline_style( 'dvloading_styles', $inline_style );

        // Custom Script
        wp_enqueue_script('dvloading-custom', plugin_dir_url( __FILE__ ) . 'js/custom.js', array( 'jquery' ), '2.0.0', true );

        $dvloading_param = array(
			"testmode" => $testmode,
            "animationstyle" => $animationstyle,
            "showskip" => $showskip,
            "barplacement" => $barplacement,
            "skipdelay" => $skipdelay,
            "showcounter" => $showcounter,
            "transition" => $transition,
            "pagetransition" => $pagetransition,
            "imageanimation" => $imageanimation,
            "imageduration" => $imageduration
		);
		wp_localize_script('dvloading-custom', 'dvloading_vars', $dvloading_param);

        ob_start();
        include_once('shortcode-output.php');
        $content = ob_get_clean();
        return $content;
    }

    /* Enqueue Scripts */
    public function enqueue_scripts(){
        wp_enqueue_script('dvloading_fix', plugin_dir_url( __FILE__ ) . 'js/fix.js', array( 'jquery' ), '1.0.0', false );

        if ( ! self::$add_scripts ) {
            return;
        }
        // Get Settings
        $showcounter = dvloading_get_option('dvloading_options_2','showcounter', 'enable' );
        $transition = dvloading_get_option('dvloading_options','transition', 'enable' );
        $imageanimation = dvloading_get_option('dvloading_options_2','imageanimation', 'enable' );

        if ( $transition == 'enable' ) {
            wp_enqueue_style('dvloading_animations', plugin_dir_url( __FILE__ ) . 'css/animations.css', true, '1.0');
        }
        if ($imageanimation != 'disable') {
            wp_enqueue_style('dvloading_imganimations', plugin_dir_url( __FILE__ ) . 'css/imganimations.css', true, '1.0');
        }
        if ( $showcounter == 'enable' ) {
            wp_enqueue_script('dvloading_counter', plugin_dir_url( __FILE__ ) . 'js/counter.js', array( 'jquery' ), '1.0.0', true );
        }
    }
}

/**
 * Returns the main instance of TMuserBlog.
 */
function DVloadingShortcode() {  
	return DVloadingShortcode::instance();
}
// Global for backwards compatibility.
$GLOBALS['DVloadingShortcode'] = DVloadingShortcode();